package com.ruoyi.system.mapper.projectV2;

import com.ruoyi.system.domain.projectV2.ZsyzJzqk;

import java.util.List;

/**
 * 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)Mapper接口
 * 
 * @author boman
 * @date 2023-02-25
 */
public interface ZsyzJzqkMapper 
{
    /**
     * 查询招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * 
     * @param id 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)主键
     * @return 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     */
    public ZsyzJzqk selectZsyzJzqkById(Long id);

    /**
     * 查询招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)列表
     * 
     * @param zsyzJzqk 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * @return 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)集合
     */
    public List<ZsyzJzqk> selectZsyzJzqkList(ZsyzJzqk zsyzJzqk);

    /**
     * 新增招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * 
     * @param zsyzJzqk 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * @return 结果
     */
    public int insertZsyzJzqk(ZsyzJzqk zsyzJzqk);

    /**
     * 修改招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * 
     * @param zsyzJzqk 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * @return 结果
     */
    public int updateZsyzJzqk(ZsyzJzqk zsyzJzqk);

    /**
     * 删除招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * 
     * @param id 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)主键
     * @return 结果
     */
    public int deleteZsyzJzqkById(Long id);

    /**
     * 批量删除招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZsyzJzqkByIds(Long[] ids);
}
