package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.projectV2.ZsyzJzqk;
import com.ruoyi.system.service.projectV2.IZsyzJzqkService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)Controller
 * 
 * @author boman
 * @date 2023-02-25
 */
@RestController
@RequestMapping("/projectV2/jzqk")
public class ZsyzJzqkController extends BaseController
{
    @Autowired
    private IZsyzJzqkService zsyzJzqkService;

    /**
     * 查询招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:jzqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzJzqk zsyzJzqk)
    {
        startPage();
        List<ZsyzJzqk> list = zsyzJzqkService.selectZsyzJzqkList(zsyzJzqk);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)列表
     */
    @PreAuthorize("@ss.hasPermi('projectV2:jzqk:export')")
    @Log(title = "招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzJzqk zsyzJzqk)
    {
        List<ZsyzJzqk> list = zsyzJzqkService.selectZsyzJzqkList(zsyzJzqk);
        ExcelUtil<ZsyzJzqk> util = new ExcelUtil<ZsyzJzqk>(ZsyzJzqk.class);
        util.exportExcel(response, list, "招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)数据");
    }

    /**
     * 获取招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)详细信息
     */
    @PreAuthorize("@ss.hasPermi('projectV2:jzqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzJzqkService.selectZsyzJzqkById(id));
    }

    /**
     * 新增招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     */
    @PreAuthorize("@ss.hasPermi('projectV2:jzqk:add')")
    @Log(title = "招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzJzqk zsyzJzqk)
    {
        return toAjax(zsyzJzqkService.insertZsyzJzqk(zsyzJzqk));
    }

    /**
     * 修改招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     */
    @PreAuthorize("@ss.hasPermi('projectV2:jzqk:edit')")
    @Log(title = "招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzJzqk zsyzJzqk)
    {
        return toAjax(zsyzJzqkService.updateZsyzJzqk(zsyzJzqk));
    }

    /**
     * 删除招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)
     */
    @PreAuthorize("@ss.hasPermi('projectV2:jzqk:remove')")
    @Log(title = "招商引资_进展情况(跟督办关系 项目需要按照固定时间内,填写进展情况否则生成督办单)", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzJzqkService.deleteZsyzJzqkByIds(ids));
    }
}
